@@ -2,6 +2,7 @@ package ClamTk::App;
 
 use strict;
 use Carp qw/croak/;
+use Net::DNS;
 $|++;
 
 use encoding 'utf8';
@@ -20,52 +21,20 @@ sub new {
     $self->{prefs}     = $self->{clamtk} . "/prefs";
     $self->{db}        = $self->{clamtk} . "/db";
 
-    $self->{freshclam}
-        = ( -e '/usr/bin/freshclam' ) ? '/usr/bin/freshclam'
+    $self->{freshclam} =
+          ( -e '/usr/bin/freshclam' )       ? '/usr/bin/freshclam'
         : ( -e '/usr/local/bin/freshclam' ) ? '/usr/local/bin/freshclam'
         : ( -e '/opt/local/bin/freshclam' ) ? '/opt/local/bin/freshclam'
         :                                     croak "freshclam not found!\n";
 
-    $self->{clampath}
-        = ( -e '/usr/bin/clamscan' ) ? '/usr/bin/clamscan'
+    $self->{clampath} =
+          ( -e '/usr/bin/clamscan' )       ? '/usr/bin/clamscan'
         : ( -e '/usr/local/bin/clamscan' ) ? '/usr/local/bin/clamscan'
         : ( -e '/opt/local/bin/clamscan' ) ? '/opt/local/bin/clamscan'
         :                                    croak "clamscan not found!\n";
 
     $self->{clamscan} = $self->{clampath};
 
-    # Below is a stupid hack because Debian ripped
-    # rar/unrar and apparently unzip functionality from ClamAV.
-    # And CentOS. And OpenSuse. And...
-    # Just removing it altogether for now.
-    #if ( -e '/etc/issue' ) {
-    #    if ( open( my $issue, "<", '/etc/issue' ) ) {
-    #        my $slurp = do {
-    #            local $/ = undef;
-    #            <$issue>;
-    #        };
-    #        close($issue);
-    #        if ( $slurp !~ /Debian|Ubuntu|CentOS/gi ) {
-    #            $self->{clamscan} .=
-    #                  ( -e '/usr/bin/unrar' ) ? ' --unrar=/usr/bin/unrar'
-    #                : ( -e '/usr/bin/rar' )   ? ' --unrar=/usr/bin/rar'
-    #                : ( -e '/usr/local/bin/unrar' )
-    #                ? '--unrar=/usr/local/bin/unrar'
-    #                : ( -e '/usr/local/bin/rar' )
-    #                ? '--unrar=/usr/local/bin/rar'
-    #                : '';
-    #
-    #            $self->{clamscan} .=
-    #                  ( -e '/usr/bin/unzip' ) ? ' --unzip=/usr/bin/unzip'
-    #                : ( -e '/usr/local/bin/unzip' )
-    #                ? ' --unzip=/usr/local/bin/unzip'
-    #                : '';
-    #        }
-    #    }
-    #}
-
-    # End of stupid hack
-
     $self->{clamscan} .= " --no-summary --block-encrypted ";
 
     return bless( $self, $class );
@@ -97,14 +66,12 @@ sub def_paths {
     for my $dir_list (@dirs) {
         if ( -e "$dir_list/daily.cld" ) {
             $DAILY_PATH = "$dir_list/daily.cld";
-        }
-        elsif ( -e "$dir_list/daily.cvd" ) {
+        } elsif ( -e "$dir_list/daily.cvd" ) {
             $DAILY_PATH = "$dir_list/daily.cvd";
         }
         if ( -e "$dir_list/main.cld" ) {
             $MAIN_PATH = "$dir_list/main.cld";
-        }
-        elsif ( -e "$dir_list/main.cvd" ) {
+        } elsif ( -e "$dir_list/main.cvd" ) {
             $MAIN_PATH = "$dir_list/main.cvd";
         }
         last if ( $DAILY_PATH && $MAIN_PATH );
@@ -143,30 +110,31 @@ sub get_AV_version {
 sub get_AV_remote {
     my ($class)  = shift;
     my ($self)   = shift;
-    my $host_cmd = '/usr/bin/host';
-    if ( not -e $host_cmd ) {
-        return 'unavailable';
-    }
     my $rmt_host = 'current.cvd.clamav.net';
 
-    # set the alarm in case we're not connected to the
-    # worldwide intertubes
-    my $get;
-    eval {
-        local $SIG{ALRM} = sub { die "failed\n" };
-        alarm 3;
-        ($get) = `$host_cmd -t txt $rmt_host`;
-        alarm 0;
-    };
-    if ( $@ && $@ eq "failed\n" ) {
+    # No longer need the alarm to "die" since Net::DNS
+    # does it for us.
+    # Just to be sure, we'll use OpenDNS servers here
+    # and set a UDP timeout.
+    my ( $get, $res );
+    $res = Net::DNS::Resolver->new(
+        nameservers => [
+            qw(208.67.222.222 208.67.220.220
+                208.67.222.220 208.67.220.222)
+        ],
+        udp_timeout => 3,
+    );
+
+    ($get) = $res->send( $rmt_host, "TXT" );
+    if ( !$get ) {
+        warn $res->errorstring, "\n";
         return 'undef';
     }
     chomp($get);
 
-    if ( $get =~ /.*?"(.*?):/ ) {
+    if ( $get->string =~ /IN\s+TXT\s+\"(.*?):/ ) {
         return $1;
-    }
-    else {
+    } else {
         return 'undef';
     }
 }
@@ -188,18 +156,16 @@ sub get_sig_info {
         my $FILE;
         if ( open( $FILE, "<", $MAIN_PATH ) ) {
             while (<$FILE>) {
-                if (/ClamAV-VDB:\S+\s+\S+\s+\S+.*?\+\d+:\d+:(\d+)/) {
+                if (/ClamAV-VDB:\S+\s+\S+\s+\S+.*?[\-\+]\d+:\d+:(\d+)/) {
                     $INFO_MAIN = $1;
                     last;
                 }
                 close($FILE);
             }
-        }
-        else {
+        } else {
             $INFO_MAIN = 0;
         }
-    }
-    else {
+    } else {
         $INFO_MAIN = 0;
     }
 
@@ -207,15 +173,14 @@ sub get_sig_info {
         my $FILE;
         if ( open( $FILE, "<", $DAILY_PATH ) ) {
             while (<$FILE>) {
-                if (/ClamAV-VDB:(\S+\s+\S+\s+\S+).*\+\d+:\d+:(\d+)/) {
+                if (/ClamAV-VDB:(\S+\s+\S+\s+\S+).*[\-\+]\d+:\d+:(\d+)/) {
                     $INFO_DATE  = $1;
                     $INFO_DAILY = $2;
                     last;
                 }
             }
             close($FILE);
-        }
-        else {
+        } else {
             $INFO_DATE  = '01 Jan 1970';
             $INFO_DAILY = 0;
         }
