@@ -71,8 +71,7 @@ sub start_gui {
     $window->set_resizable(FALSE);
     if ( -e "/usr/share/pixmaps/clamtk.png" ) {
         $window->set_default_icon_from_file("/usr/share/pixmaps/clamtk.png");
-    }
-    elsif ( -e "/usr/share/pixmaps/clam.xpm" ) {
+    } elsif ( -e "/usr/share/pixmaps/clam.xpm" ) {
         $window->set_default_icon_from_file("/usr/share/pixmaps/clam.xpm");
     }
 
@@ -244,8 +243,8 @@ sub start_gui {
     $tt->set_tip( $file_btn, gettext('Scan a file') );
     $bbox->add($file_btn);
 
-    my $dir_img
-        = Gtk2::Image->new_from_stock( 'gtk-directory', 'small-toolbar' );
+    my $dir_img =
+        Gtk2::Image->new_from_stock( 'gtk-directory', 'small-toolbar' );
     my $dir_btn = Gtk2::Button->new();
     $dir_btn->signal_connect( clicked => sub { getfile('dir') } );
     $dir_btn->set_property( 'image' => $dir_img );
@@ -298,8 +297,8 @@ sub start_gui {
     my $engine_gui_box = Gtk2::HBox->new( TRUE, 0 );
     my $engine_text = Gtk2::Label->new( gettext('Antivirus engine') );
     $engine_version_text = Gtk2::Label->new( gettext('Unknown') );
-    $engine_gui_img
-        = Gtk2::Image->new_from_stock( 'gtk-apply', 'small-toolbar' );
+    $engine_gui_img =
+        Gtk2::Image->new_from_stock( 'gtk-apply', 'small-toolbar' );
     $tt->set_tip( $engine_gui_img, gettext('Current') );
     $engine_gui_box->pack_start( $engine_gui_img,      TRUE, TRUE, 0 );
     $engine_gui_box->pack_start( $engine_text,         TRUE, TRUE, 0 );
@@ -309,8 +308,8 @@ sub start_gui {
     my $status_gui_box   = Gtk2::HBox->new( TRUE, 0 );
     my $gui_text         = Gtk2::Label->new( gettext('GUI version') );
     my $gui_version_text = Gtk2::Label->new( $self->{VERSION} );
-    $status_gui_img
-        = Gtk2::Image->new_from_stock( 'gtk-apply', 'small-toolbar' );
+    $status_gui_img =
+        Gtk2::Image->new_from_stock( 'gtk-apply', 'small-toolbar' );
     $tt->set_tip( $status_gui_img, gettext('Current') );
     $status_gui_box->pack_start( $status_gui_img,   TRUE, TRUE, 0 );
     $status_gui_box->pack_start( $gui_text,         TRUE, TRUE, 0 );
@@ -320,8 +319,8 @@ sub start_gui {
     my $defs_gui_box = Gtk2::HBox->new( TRUE, 0 );
     my $defs_text = Gtk2::Label->new( gettext('Virus definitions') );
     $defs_version_text = Gtk2::Label->new( gettext('Unknown') );
-    $defs_gui_img
-        = Gtk2::Image->new_from_stock( 'gtk-apply', 'small-toolbar' );
+    $defs_gui_img =
+        Gtk2::Image->new_from_stock( 'gtk-apply', 'small-toolbar' );
     $tt->set_tip( $defs_gui_img, gettext('Current') );
     $defs_gui_box->pack_start( $defs_gui_img,      TRUE, TRUE, 0 );
     $defs_gui_box->pack_start( $defs_text,         TRUE, TRUE, 0 );
@@ -329,8 +328,8 @@ sub start_gui {
     $status_table->attach_defaults( $defs_gui_box, 0, 3, 2, 3 );
 
     my $last_gui_box = Gtk2::HBox->new( TRUE, 0 );
-    my $last_gui_img
-        = Gtk2::Image->new_from_stock( 'gtk-print-preview', 'small-toolbar' );
+    my $last_gui_img =
+        Gtk2::Image->new_from_stock( 'gtk-print-preview', 'small-toolbar' );
     my $last_text = Gtk2::Label->new( gettext('Last virus scan') );
     $last_date_text = Gtk2::Label->new( gettext('Unknown') );
     $tt->set_tip( $last_gui_img, gettext('Date of your last virus scan') );
@@ -340,8 +339,8 @@ sub start_gui {
     $status_table->attach_defaults( $last_gui_box, 0, 3, 3, 4 );
 
     my $last_infect_box = Gtk2::HBox->new( TRUE, 0 );
-    my $last_infect_img
-        = Gtk2::Image->new_from_stock( 'gtk-dnd', 'small-toolbar' );
+    my $last_infect_img =
+        Gtk2::Image->new_from_stock( 'gtk-dnd', 'small-toolbar' );
     my $last_infect_text = Gtk2::Label->new( gettext('Last infected file') );
     $last_infect_date = Gtk2::Label->new( gettext('Unknown') );
     $tt->set_tip( $last_infect_img, gettext('Date of last known infection') );
@@ -373,8 +372,8 @@ sub start_gui {
         0 );
     $pb->set_fraction(0);
 
-    my $stop_image
-        = Gtk2::Image->new_from_stock( 'gtk-stop', 'small-toolbar' );
+    my $stop_image =
+        Gtk2::Image->new_from_stock( 'gtk-stop', 'small-toolbar' );
     my $stop_btn = Gtk2::Button->new();
     $stop_btn->set_property( image => $stop_image );
     $stop_btn->set_relief('none');
@@ -425,25 +424,24 @@ sub start_gui {
             my $d = abs_path( $ARGV[0] );
             if ( not $d ) {    # no permissions
                 $found->{$found_count}->{name} = $ARGV[0];
-                $found->{$found_count}->{status}
-                    = gettext("Could not scan (permissions)");
+                $found->{$found_count}->{status} =
+                    gettext("Could not scan (permissions)");
                 $found->{$found_count}->{action} = gettext("None");
                 $found_count++;
                 ClamTk::Results->display( $main::scanner, 1, $found );
                 clean_up();
             } elsif ( $ARGV[0] =~ m#^/(proc|sys|dev)# ) {
                 $found->{$found_count}->{name} = $ARGV[0];
-                $found->{$found_count}->{status} = gettext("Directory excluded from scan");
+                $found->{$found_count}->{status} =
+                    gettext("Directory excluded from scan");
                 $found->{$found_count}->{action} = gettext("None");
                 $found_count++;
                 ClamTk::Results->display( $main::scanner, 1, $found );
                 clean_up();
-	    }
-            else {
+            } else {
                 getfile( 'cmd-scan', $d );
             }
-        }
-        else {
+        } else {
             my $pos = 0;
             for my $f (@ARGV) {
                 $f = abs_path($f);
@@ -456,8 +454,7 @@ sub start_gui {
             }
             getfile( 'cmd-scan', @ARGV );
         }
-    }
-    else {
+    } else {
         update_status_frame();
     }
 
@@ -484,28 +481,24 @@ sub update_status_frame {
         $tt->set_tip( $engine_gui_img, gettext('Unable to check') );
         $window->queue_draw;
         Gtk2->main_iteration while ( Gtk2->events_pending );
-    }
-    elsif ( ( $version cmp $av_remote ) == -1 ) {
+    } elsif ( ( $version cmp $av_remote ) == -1 ) {
         $engine_gui_img->set_from_stock( 'gtk-dialog-error',
             'small-toolbar' );
         $tt->set_tip( $engine_gui_img,
             gettext('The antivirus engine is reporting an outdated engine') );
         $window->queue_draw;
         Gtk2->main_iteration while ( Gtk2->events_pending );
-    }
-    elsif ( ( $version cmp $av_remote ) == 0 ) {
+    } elsif ( ( $version cmp $av_remote ) == 0 ) {
         $engine_gui_img->set_from_stock( 'gtk-apply', 'small-toolbar' );
         $tt->set_tip( $engine_gui_img, gettext('Current') );
         $window->queue_draw;
         Gtk2->main_iteration while ( Gtk2->events_pending );
-    }
-    elsif ( ( $version cmp $av_remote ) == 1 ) {    # shouldn't happen
+    } elsif ( ( $version cmp $av_remote ) == 1 ) {    # shouldn't happen
         $engine_gui_img->set_from_stock( 'gtk-apply', 'small-toolbar' );
         $tt->set_tip( $engine_gui_img, gettext('Current') );
         $window->queue_draw;
         Gtk2->main_iteration while ( Gtk2->events_pending );
-    }
-    else {
+    } else {
         $engine_gui_img->set_from_stock( 'gtk-dialog-question',
             'small-toolbar' );
         $tt->set_tip( $engine_gui_img, gettext('Unable to check') );
@@ -520,12 +513,10 @@ sub update_status_frame {
         $status_gui_img->set_from_stock( 'gtk-dialog-question',
             'small-toolbar' );
         $tt->set_tip( $status_gui_img, gettext('Unable to check') );
-    }
-    elsif ( $ret == 1 || $ret == 3 ) {
+    } elsif ( $ret == 1 || $ret == 3 ) {
         $status_gui_img->set_from_stock( 'gtk-apply', 'small-toolbar' );
         $tt->set_tip( $status_gui_img, gettext('Current') );
-    }
-    else {
+    } else {
         $status_gui_img->set_from_stock( 'gtk-dialog-error',
             'small-toolbar' );
         $tt->set_tip( $status_gui_img,
@@ -543,8 +534,7 @@ sub update_status_frame {
     if ( $Config->{_}->{LastScan} ) {
         $last_scan = $Config->{_}->{LastScan};
         $last_date_text->set_text($last_scan);
-    }
-    else {
+    } else {
         $last_date_text->set_text( gettext('Never') );
     }
 
@@ -552,8 +542,7 @@ sub update_status_frame {
     if ( $Config->{_}->{LastInfection} ) {
         my $last_infection = $Config->{_}->{LastInfection};
         $last_infect_date->set_text($last_infection);
-    }
-    else {
+    } else {
         $last_infect_date->set_text( gettext('Never') );
     }
     $top_label->set_text("");
@@ -567,8 +556,7 @@ sub set_sig_status {
     my $sig_date = ClamTk::App->get_date_sigs();
     if ($sig_date) {
         $defs_version_text->set_text($sig_date);
-    }
-    else {
+    } else {
         $defs_version_text->set_text( gettext("None found") );
     }
 
@@ -578,8 +566,7 @@ sub set_sig_status {
         $defs_gui_img->set_from_stock( 'gtk-dialog-error', 'small-toolbar' );
         $tt->set_tip( $defs_gui_img,
             gettext('Your antivirus signatures are out-of-date') );
-    }
-    else {
+    } else {
         $defs_gui_img->set_from_stock( 'gtk-apply', 'small-toolbar' );
         $tt->set_tip( $defs_gui_img, 'Current' );
     }
@@ -594,12 +581,10 @@ sub set_tk_status {
         $status_gui_img->set_from_stock( 'gtk-dialog-question',
             'small-toolbar' );
         $tt->set_tip( $status_gui_img, gettext('Unable to check') );
-    }
-    elsif ( $ret == 1 || $ret == 3 ) {
+    } elsif ( $ret == 1 || $ret == 3 ) {
         $status_gui_img->set_from_stock( 'gtk-apply', 'small-toolbar' );
         $tt->set_tip( $status_gui_img, gettext('Current') );
-    }
-    else {
+    } else {
         $status_gui_img->set_from_stock( 'gtk-dialog-error',
             'small-toolbar' );
         $tt->set_tip( $status_gui_img,
@@ -629,13 +614,12 @@ sub date_diff {
     );
     return unless ( $day2 && $month2 && $year2 );
 
-    my $diff = Delta_Days( $year1, $month1, $day1, $year2, $months{$month2},
-        $day2 );
+    my $diff =
+        Delta_Days( $year1, $month1, $day1, $year2, $months{$month2}, $day2 );
     $diff *= -1;
     if ( $diff >= 7 ) {
         return 'outdated';
-    }
-    else {
+    } else {
         return 'current';
     }
 }
@@ -647,8 +631,7 @@ sub getfile {
     # these lines are for 'thorough' :)
     if ($thorough) {
         $main::scanner->{clamscan} .= " --detect-pua --detect-broken";
-    }
-    elsif ( !$thorough ) {
+    } elsif ( !$thorough ) {
         $main::scanner->{clamscan} =~ s/\s--detect-pua --detect-broken//;
     }
 
@@ -673,8 +656,8 @@ sub getfile {
     $rule->maxdepth(1)
         unless ( $option eq 'recur' or $option eq 'full-home' );
 
-    my $title
-        = ( $option eq 'file' ) ? gettext('Select File')
+    my $title =
+          ( $option eq 'file' ) ? gettext('Select File')
         : ( $option eq 'dir' )
         ? gettext('Select a Directory (directory scan)')
         : ( $option eq 'recur' )
@@ -685,8 +668,7 @@ sub getfile {
         $scan_status_label->set_text( gettext("Please wait...") );
         Gtk2->main_iteration while ( Gtk2->events_pending );
         @files = $rule->in( $main::scanner->{directory} );
-    }
-    elsif ( $option eq 'file' ) {
+    } elsif ( $option eq 'file' ) {
         $dialog = Gtk2::FileChooserDialog->new(
             gettext($title), undef, 'open',
             'gtk-cancel' => 'cancel',
@@ -702,18 +684,15 @@ sub getfile {
             $dialog->destroy;
             $window->queue_draw;
             Gtk2->main_iteration while ( Gtk2->events_pending );
-        }
-        else {
+        } else {
             $dialog->destroy;
             return;
         }
-    }
-    elsif ( $option eq 'full-home' ) {
+    } elsif ( $option eq 'full-home' ) {
         $scan_status_label->set_text( gettext("Please wait...") );
         Gtk2->main_iteration while ( Gtk2->events_pending );
         @files = $rule->in( $main::scanner->{directory} );
-    }
-    elsif ( $option eq 'dir' or $option eq 'recur' ) {
+    } elsif ( $option eq 'dir' or $option eq 'recur' ) {
         $dialog = Gtk2::FileChooserDialog->new(
             gettext($title), undef,
             'select-folder',
@@ -727,8 +706,8 @@ sub getfile {
             {
                 $dialog->destroy;
                 $found->{$found_count}->{name} = $dir;
-                $found->{$found_count}->{status}
-                    = ( not -r $dir )
+                $found->{$found_count}->{status} =
+                    ( not -r $dir )
                     ? gettext("Could not scan (permissions)")
                     : gettext("Will not scan that directory");
                 $found->{$found_count}->{action} = gettext("None");
@@ -745,28 +724,24 @@ sub getfile {
             $dir ||= $main::scanner->{directory};
             Gtk2->main_iteration while ( Gtk2->events_pending );
             @files = $rule->in($dir);
-        }
-        else {
+        } else {
             $dialog->destroy;
             return;
         }
-    }
-    elsif ( $option eq 'cmd-scan' ) {
+    } elsif ( $option eq 'cmd-scan' ) {
         if ( -d $cmd_input[0] ) {
             $scan_status_label->set_text( gettext("Please wait...") );
             $window->queue_draw;
 
             Gtk2->main_iteration while ( Gtk2->events_pending );
             @files = $rule->in( $cmd_input[0] );
-        }
-        else {
+        } else {
             $scan_status_label->set_text( gettext("Please wait...") );
             $window->queue_draw;
             Gtk2->main_iteration while ( Gtk2->events_pending );
             @files = @cmd_input;
         }
-    }
-    else {
+    } else {
         die gettext("Shouldn't reach this."), "\n";
     }
 
@@ -788,8 +763,7 @@ sub getfile {
     while ( $index <= $#files ) {
         if ( -l $files[$index] && !-e $files[$index] ) {
             splice( @files, $index, 1 );
-        }
-        else {
+        } else {
             $index++;
         }
     }
@@ -797,19 +771,16 @@ sub getfile {
     # only a single file
     if ( $option eq 'file' ) {
         scan(@files);
-    }
-    else {
+    } else {
         if ( $hidden == 0 && $option ne 'recur' && $option ne 'full-home' ) {
             @files = grep { basename($_) !~ /^\./ } @files;
         }
 
         if ( scalar(@files) == 1 ) {
             $step = 1;
-        }
-        elsif ( scalar(@files) > 1 ) {
+        } elsif ( scalar(@files) > 1 ) {
             $step = 1 / scalar(@files);
-        }
-        else {
+        } else {
             $step = 1;
         }
 
@@ -818,8 +789,7 @@ sub getfile {
             foreach my $foo (@files) {
                 if ( -s $foo >= 20_000_000 ) {
                     push( @large, $foo );
-                }
-                else {
+                } else {
                     push( @new, $foo );
                 }
             }
@@ -834,8 +804,7 @@ sub getfile {
                     next;
                 }
             }
-        }
-        else {
+        } else {
             @new = @files;
         }
 
@@ -847,8 +816,7 @@ sub getfile {
                 if ( scalar(@send) == 255 ) {
                     scan(@send);
                     @send = ();
-                }
-                else {
+                } else {
                     next;
                 }
             }
@@ -899,8 +867,7 @@ sub scan {
         if (/(.*?): (.*?) FOUND/) {
             $file   = $1;
             $status = $2;
-        }
-        elsif (/(.*?): (OK)/) {
+        } elsif (/(.*?): (OK)/) {
             $file   = $1;
             $status = $2;
         }    #else {
@@ -942,8 +909,7 @@ sub scan {
         if ( $num_so_far > 0 ) {
             $mid_status->set_markup(
                 sprintf gettext("<b>Viruses Found: %d</b>"), $num_so_far );
-        }
-        else {
+        } else {
             $mid_status->set_text( sprintf gettext("Viruses Found: %d"),
                 $num_so_far );
         }
@@ -952,8 +918,7 @@ sub scan {
         # Pulse!
         if ( $current + $step <= 0 || $current + $step >= 1.0 ) {
             $current = .99;
-        }
-        else {
+        } else {
             $current += $step;
         }
 
@@ -1024,11 +989,9 @@ sub clean_up {
         $li = "$day $mon $year";
         $last_infect_date->set_text("$day $mon $year");
         $window->queue_draw;
-    }
-    elsif ( $Config->{_}->{LastInfection} ) {
+    } elsif ( $Config->{_}->{LastInfection} ) {
         $li = $Config->{_}->{LastInfection};
-    }
-    else {
+    } else {
         $li = gettext("Never");
     }
 
@@ -1046,8 +1009,8 @@ sub clean_up {
     Gtk2->main_iteration while ( Gtk2->events_pending );
 
     if ($save_log) {
-        my $virus_log
-            = $main::scanner->{history} . "/" . "$mon-$day-$year" . ".log";
+        my $virus_log =
+            $main::scanner->{history} . "/" . "$mon-$day-$year" . ".log";
 
         # sort the directories scanned for display
         my @sorted = sort { $a cmp $b } keys %dirs_scanned;
@@ -1065,8 +1028,7 @@ sub clean_up {
                 $num_so_far == 1 ? gettext("virus") : gettext("viruses"),
                 $num_scanned,
                 $num_scanned == 1 ? gettext("file") : gettext("files");
-        }
-        else {
+        } else {
             $scan_status_label->set_text(
                 gettext("Could not write to logfile. Check permissions.") );
             $save_log = 0;
@@ -1086,8 +1048,7 @@ sub clean_up {
 
     if ( $num_so_far == 0 ) {
         print $REPORT gettext("No viruses found.\n") if ($save_log);
-    }
-    else {
+    } else {
         if ($save_log) {
             for my $num ( sort keys %$found ) {
                 printf $REPORT "%-38s %38s\n",
@@ -1102,8 +1063,7 @@ sub clean_up {
 
     if ($num_so_far) {
         ClamTk::Results->display( $main::scanner, 0, $found );
-    }
-    elsif ( !keys %$found && $scan_option eq 'cmd-scan' ) {
+    } elsif ( !keys %$found && $scan_option eq 'cmd-scan' ) {
         for my $f (@files) {
             $found->{$found_count}->{name}   = $f;
             $found->{$found_count}->{status} = gettext("Nothing detected");
@@ -1129,8 +1089,8 @@ sub show_message_dialog {
     my ( $parent, $type, $button, $message ) = @_;
 
     my $dialog;
-    $dialog
-        = Gtk2::MessageDialog->new_with_markup( $parent,
+    $dialog =
+        Gtk2::MessageDialog->new_with_markup( $parent,
         [qw(modal destroy-with-parent)],
         $type, $button, $message );
 
@@ -1241,8 +1201,7 @@ sub quarantine_check {
     if ( !$del ) {
         show_message_dialog( $window, 'info', 'ok',
             gettext("No items currently quarantined.") );
-    }
-    else {
+    } else {
         my $notice = sprintf gettext("%d item(s) currently quarantined."),
             $del;
         show_message_dialog( $window, 'info', 'ok', $notice );
@@ -1254,19 +1213,17 @@ sub del_quarantined {
         show_message_dialog( $window, 'error', 'close',
             gettext("There is no quarantine directory to empty.") );
         return;
-    }
-    else {
+    } else {
         my $confirm_message = gettext("Really delete all quarantined files?");
-        my $confirm
-            = Gtk2::MessageDialog->new( $window,
+        my $confirm =
+            Gtk2::MessageDialog->new( $window,
             [qw(modal destroy-with-parent)],
             'question', 'ok-cancel', $confirm_message );
 
         if ( "cancel" eq $confirm->run ) {
             $confirm->destroy;
             return;
-        }
-        else {
+        } else {
             $confirm->destroy;
             my @trash;
             unless ( opendir( DIR, $main::scanner->{viruses} ) ) {
@@ -1279,8 +1236,7 @@ sub del_quarantined {
             if ( scalar(@trash) == 0 ) {
                 show_message_dialog( $window, 'info', 'close',
                     gettext("There are no quarantined items to delete.") );
-            }
-            else {
+            } else {
                 my $del = 0;
                 foreach (@trash) {
                     unlink "$main::scanner->{viruses}/$_" and $del++;
@@ -1364,15 +1320,14 @@ sub history_del_single {
 sub history_del_all {
     return unless (@h_files);
     my $confirm_message = gettext("Really delete all history logs?");
-    my $confirm
-        = Gtk2::MessageDialog->new( $window, [qw(modal destroy-with-parent)],
+    my $confirm =
+        Gtk2::MessageDialog->new( $window, [qw(modal destroy-with-parent)],
         'question', 'ok-cancel', $confirm_message );
 
     if ( "cancel" eq $confirm->run ) {
         $confirm->destroy;
         return;
-    }
-    else {
+    } else {
         $confirm->destroy;
         my @not_del;
         my $size = @h_files;
@@ -1382,8 +1337,7 @@ sub history_del_all {
         if ( scalar(@not_del) >= 1 ) {
             $h_label->set_text(
                 sprintf gettext("Could not delete files: %s!"), @not_del );
-        }
-        else {
+        } else {
             show_message_dialog( $window, 'info', 'ok',
                 gettext("Successfully removed history logs.") );
         }
@@ -1468,29 +1422,27 @@ sub save_prefs {
     my ( $ls, $li, $update );
     if ( $Config->{_}->{Update} ) {
         $update = $Config->{_}->{Update};
-    }
-    else {
+    } else {
         $update = 'undef';
     }
 
     if ( $Config->{_}->{LastScan} ) {
         $ls = $Config->{_}->{LastScan};
-    }
-    else {
+    } else {
         $ls = gettext("Never");
     }
     if ( $Config->{_}->{LastInfection} ) {
         $li = $Config->{_}->{LastInfection};
-    }
-    else {
+    } else {
         $li = gettext("Never");
     }
 
-    my $ret_val = ClamTk::Prefs->set_all( $main::scanner, $save_log, $hidden,
-        $size_set, $thorough, $ls, $li, $update );
+    my $ret_val =
+        ClamTk::Prefs->set_all( $main::scanner, $save_log, $hidden, $size_set,
+        $thorough, $ls, $li, $update );
 
-    my $msg
-        = ( $ret_val == 0 )
+    my $msg =
+        ( $ret_val == 0 )
         ? gettext("Could not save your preferences.")
         : gettext("Your preferences were saved.");
 
@@ -1502,39 +1454,48 @@ sub about {
     $about->set_authors("Dave M, dave.nerd <at> gmail.com");
     $about->set_version( $main::scanner->{VERSION} );
     my @translators = (
+	'Nawaf AsSulami, Arabic (ar_SA)',
         'Karel Hudan, Czech (cs_CZ)',
         'Jimmy Christensen, Danish (da_DK)',
         'Ronny Steiner, German (de_DE)',
+        'Alexandros Chatzicharalambidis, Greek (el_GR)',
         'Mariano Rojo, Spanish (es_ES)',
+        'Heriberto  Cantú, Spanish (es_ES)',
         'Alain Bernard, French (fr_FR)',
         'David Garcia Rojo, French (fr_FR)',
         'Viale Fabrice, French (fr_FR)',
         'Arnaud Dubois, French (fr_FR)',
+        'Sébastien, French (fr_FR)',
         'Román Pena, Galician (gl_ES)',
         'Edoardo Tosca, Italian (it_IT)',
         'Tobia Fasciati, Italian (it_IT)',
         'Alessandro Volturno, Italian (it_IT)',
         'Gina C, Korean (ko_KR)',
+        'Eun Joon Kim, Korean (ko_KR)',
+        'Frederik Mattelaere, Dutch (nl_BE)',
         'Rob van den Berg, Dutch (nl_NL)',
         'Robert Tomasik, Polish (pl_PL)',
         'Piotr Makowski, Polish (pl_PL)',
         'Bruno Diniz, Portugese (pt_BR)',
+        'Felipe Augusto, Portugese (pt_BR)',
         'Veronica B., Romanian (ro_RO)',
+        'Adrian Mowrey, Romanian (ro_RO)',
         'Vitaly Lipatov, Russian (ru_RU)',
+        'Tomáš Vadina, Slovak (sk)',
         'Martin McDowell, Slovene (sl_SI)',
         'Petter Viklund, Swedish (sv_SE)',
+        'Gürkan Gür, Turkish (tr_TR)',
         'Tao Wei, Chinese (zh_CN)',
         'Aron Xu, Chinese (zh_CN)',
     );
-    my @artists
-        = ( 'Edoardo Tosca (Website Design)', 'Gerald Ganson (Icon Design)',
-        );
+    my @artists =
+        ( 'Edoardo Tosca (Website Design)', 'Gerald Ganson (Icon Design)', );
     my $t_list = join "\n", @translators;
     $about->set_translator_credits($t_list);
     my $a_list = join "\n", @artists;
     $about->set_artists($a_list);
-    my $logo
-        = -e '/usr/share/pixmaps/clamtk.png' ? '/usr/share/pixmaps/clamtk.png'
+    my $logo =
+          -e '/usr/share/pixmaps/clamtk.png' ? '/usr/share/pixmaps/clamtk.png'
         : 'usr/share/pixmaps/clamtk.xpm'     ? '/usr/share/pixmaps/clamtk.xpm'
         :                                      '';
     my $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($logo);
@@ -1543,7 +1504,7 @@ sub about {
     $about->set_comments(
         "ClamTk is a GUI front-end for the ClamAV antivirus using gtk2-perl."
     );
-    $about->set_license( "ClamTk, (c) 2004-2008. All rights reserved.\n\n"
+    $about->set_license( "ClamTk, (c) 2004-2009. All rights reserved.\n\n"
             . "This program is free software; you can redistribute it\n"
             . "and/or modify it under the same terms as Perl itself." );
     $about->run;
