@@ -21,23 +21,20 @@ sub start_up {
     if ( !-d $self->{viruses} ) {
         eval { mkpath( $self->{viruses}, 0, oct(777) ); };
         return 0 if ($@);
-    }
-    else {
+    } else {
         chmod oct(777), $self->{viruses};
     }
     if ( !-d $self->{history} ) {
         eval { mkpath( $self->{history}, 0, oct(777) ); };
         return 0 if ($@);
-    }
-    else {
+    } else {
         chmod oct(777), $self->{history};
     }
     if ( !-d $self->{db} ) {
         eval { mkpath( $self->{db}, 0, oct(777) ); };
         warn $@  if $@;
         return 0 if ($@);
-    }
-    else {
+    } else {
         chmod oct(777), $self->{db};
     }
     if ( !-e $self->{prefs} ) {
@@ -62,8 +59,8 @@ sub custom_prefs {
     my $li     = $pkg->{_}->{LastInfection} ||= gettext('Never');
     my $update = $pkg->{_}->{Update}        ||= 'undef';
 
-    my $count
-        = ClamTk::Prefs->set_all( $main::scanner, $sl, $sh, $limit, $t, $ls,
+    my $count =
+        ClamTk::Prefs->set_all( $main::scanner, $sl, $sh, $limit, $t, $ls,
         $li, $update );
     return $count;
 }
