@@ -23,12 +23,11 @@ sub updater {
     $win = Gtk2::Dialog->new();
     $win->signal_connect( destroy => sub { $win->destroy; } );
     $win->set_title( gettext('Updates') );
-    $win->set_default_size( 500, 125 );
+    $win->set_default_size( 625, 130 );
 
     if ( -e "/usr/share/pixmaps/clamtk.png" ) {
         $win->set_default_icon_from_file("/usr/share/pixmaps/clamtk.png");
-    }
-    elsif ( -e "/usr/share/pixmaps/clam.xpm" ) {
+    } elsif ( -e "/usr/share/pixmaps/clam.xpm" ) {
         $win->set_default_icon_from_file("/usr/share/pixmaps/clam.xpm");
     }
 
@@ -36,6 +35,8 @@ sub updater {
 
     my $update_win = Gtk2::ScrolledWindow->new();
     $win->vbox->pack_start( $update_win, TRUE, TRUE, 0 );
+    $update_win->set_policy( 'never', 'never' );
+    $update_win->set_shadow_type('etched-out');
 
     $update_list = Gtk2::SimpleList->new(
         gettext('Updates')     => 'text',
@@ -77,6 +78,7 @@ sub updater {
 
     my $hbox = Gtk2::HButtonBox->new();
     $win->vbox->pack_start( $hbox, FALSE, FALSE, 0 );
+    $hbox->set_layout_default('spread');
 
     my $go = Gtk2::Button->new( gettext('Check for updates') );
     $hbox->add($go);
@@ -91,8 +93,6 @@ sub updater {
         }
     );
 
-    #Gtk2->main_iteration while Gtk2->events_pending;
-
     $win->show_all();
     $win->run;
     $win->destroy;
@@ -105,30 +105,29 @@ sub decision {
     my $value = 0;
 
     for ( 0 .. $scalar ) {
+        Gtk2->main_iteration while Gtk2->events_pending;
         $rowref = $update_list->{data}[$_];
         if ( $rowref->[2] == 1 ) {    # is it enabled?
-            if ( $rowref->[0] eq 'Signature updates' ) {
+            if ( $rowref->[0] eq gettext('Signature updates') ) {
                 $update_list->{data}[$_][3] = gettext("Checking...");
                 $value = update_signatures();
-                $update_list->{data}[$_][3]
-                    = $value == 0 ? gettext("Update failed")
+                $update_list->{data}[$_][3] =
+                      $value == 0 ? gettext("Update failed")
                     : $value == 1 ? gettext("Signatures are current")
                     : $value == 2 ? gettext("Updated")
                     :               "";
                 ClamTk::GUI->set_sig_status();
-            }
-            elsif ( $rowref->[0] eq 'GUI updates' ) {
+            } elsif ( $rowref->[0] eq gettext('GUI updates') ) {
                 $update_list->{data}[$_][3] = gettext("Checking...");
                 $value = update_gui();
-                $update_list->{data}[$_][3]
-                    = $value == 0 ? gettext("Check failed")
+                $update_list->{data}[$_][3] =
+                      $value == 0 ? gettext("Check failed")
                     : $value == 1 ? gettext("GUI is current")
                     : $value == 2 ? gettext("A newer version is available")
                     : $value == 3 ? gettext("GUI is current")
                     :               "";
                 ClamTk::GUI->set_tk_status( $main::scanner, $value );
-            }
-            else {
+            } else {
                 warn "ref = ", $rowref->[0], "\n";
             }
         }
@@ -162,8 +161,7 @@ sub update_signatures {
     }
     if ( !@result ) {
         return 0;
-    }
-    else {
+    } else {
         foreach my $line (@result) {
             if ( $line =~ /Database updated .(\d+) signatures/ ) {
                 return 2;
@@ -203,8 +201,7 @@ sub update_gui {
         return 2 if ( $content > $version );
         return 3 if ( $version > $content );
         return 0;
-    }
-    else {
+    } else {
         return 0;
     }
 }
@@ -217,8 +214,7 @@ sub db_select {
 
     if ( -e "/usr/share/pixmaps/clamtk.png" ) {
         $choice->set_default_icon_from_file("/usr/share/pixmaps/clamtk.png");
-    }
-    elsif ( -e "/usr/share/pixmaps/clam.xpm" ) {
+    } elsif ( -e "/usr/share/pixmaps/clam.xpm" ) {
         $choice->set_default_icon_from_file("/usr/share/pixmaps/clam.xpm");
     }
 
@@ -233,8 +229,8 @@ sub db_select {
     $sw->set_policy( 'automatic', 'automatic' );
     $sw->set_border_width(5);
 
-    my $dialog
-        = gettext( "\nPlease choose how you will update your antivirus "
+    my $dialog =
+        gettext( "\nPlease choose how you will update your antivirus "
             . "signatures.\n\nIf this is a multi-user system or you have an "
             . "administrator, you should probably choose 'System Wide'.\n\n"
             . "If you need to be able to update the signatures yourself, "
@@ -337,8 +333,7 @@ sub save {
                         "$main::scanner->{db}/daily.cld"
                     );
                     $d = 1;
-                }
-                elsif ( -e "$dir_list/daily.cvd" ) {
+                } elsif ( -e "$dir_list/daily.cvd" ) {
                     system(
                         "cp",
                         "$dir_list/daily.cvd",
@@ -353,8 +348,7 @@ sub save {
                         "$main::scanner->{db}/main.cld"
                     );
                     $m = 1;
-                }
-                elsif ( -e "$dir_list/main.cvd" ) {
+                } elsif ( -e "$dir_list/main.cvd" ) {
                     system(
                         "cp",
                         "$dir_list/main.cvd",
